==> AuctioneerSuite-4.4.7010.zip: Enchantrix-Barker/BarkerObjects.lua <==
--[[
	Enchantrix:Barker Addon for World of Warcraft(tm).
	Version: 3.4.6917 (SwimmingSeadragon)
	Revision: $Id: BarkerObjects.lua 6917 2023-08-28 00:00:20Z none $
	URL: http://enchantrix.org/

	Barker namespace.

	License:
		This program is free software; you can redistribute it and/or
		modify it under the terms of the GNU General Public License
		as published by the Free Software Foundation; either version 2
		of the License, or (at your option) any later version.

		This program is distributed in the hope that it will be useful,
		but WITHOUT ANY WARRANTY; without even the implied warranty of
		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
		GNU General Public License for more details.

		You should have received a copy of the GNU General Public License
		along with this program(see GPL.txt); if not, write to the Free Software
		Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

	Note:
		This AddOn's source code is specifically designed to work with
		World of Warcraft's interpreted AddOn system.
		You have an implicit license to use this AddOn with these facilities
		since that is it's designated purpose as per:
		http://www.fsf.org/licensing/licenses/gpl-faq.html#InterpreterIncompat
]]
EnchantrixBarker_RegisterRevision("$URL: Enchantrix-Barker/BarkerObjects.lua $", "$Rev: 6917 $")

-- Barker namespace
Barker = {
	Barker = {},
	Command = {},
	Config = {},
	Constants = {},
	Container = {},
	Locale = {},
	State = {},
	Storage = {},
	Tooltip = {},
	Util = {},
}

==> AuctioneerSuite-5.12.5198.zip: Enchantrix-Barker/BarkerObjects.lua <==
--[[
	Enchantrix:Barker Addon for World of Warcraft(tm).
	Version: 5.12.5198 (QuirkyKiwi)
	Revision: $Id: BarkerObjects.lua 3581 2008-10-11 12:36:19Z Norganna $
	URL: http://enchantrix.org/

	Barker namespace.

	License:
		This program is free software; you can redistribute it and/or
		modify it under the terms of the GNU General Public License
		as published by the Free Software Foundation; either version 2
		of the License, or (at your option) any later version.

		This program is distributed in the hope that it will be useful,
		but WITHOUT ANY WARRANTY; without even the implied warranty of
		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
		GNU General Public License for more details.

		You should have received a copy of the GNU General Public License
		along with this program(see GPL.txt); if not, write to the Free Software
		Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

	Note:
		This AddOn's source code is specifically designed to work with
		World of Warcraft's interpreted AddOn system.
		You have an implicit license to use this AddOn with these facilities
		since that is it's designated purpose as per:
		http://www.fsf.org/licensing/licenses/gpl-faq.html#InterpreterIncompat
]]
EnchantrixBarker_RegisterRevision("$URL: http://svn.norganna.org/auctioneer/branches/5.12/Enchantrix-Barker/BarkerObjects.lua $", "$Rev: 3581 $")

-- Barker namespace
Barker = {
	Barker = {},
	Command = {},
	Config = {},
	Constants = {},
	Container = {},
	Locale = {},
	State = {},
	Storage = {},
	Tooltip = {},
	Util = {},
}
